@@ -15,8 +15,6 @@ import sys
 from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
-from botocore.exceptions import ClientError as Boto3ClientError
-from botocore.paginate import Paginator as Boto3Paginator
 
 from mypy_boto3_budgets.paginator import (
     DescribeBudgetsPaginator,
@@ -45,21 +43,29 @@ else:
 __all__ = ("BudgetsClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
-    AccessDeniedException: Type[Boto3ClientError]
-    ClientError: Type[Boto3ClientError]
-    CreationLimitExceededException: Type[Boto3ClientError]
-    DuplicateRecordException: Type[Boto3ClientError]
-    ExpiredNextTokenException: Type[Boto3ClientError]
-    InternalErrorException: Type[Boto3ClientError]
-    InvalidNextTokenException: Type[Boto3ClientError]
-    InvalidParameterException: Type[Boto3ClientError]
-    NotFoundException: Type[Boto3ClientError]
+    AccessDeniedException: Type[BotocoreClientError]
+    ClientError: Type[BotocoreClientError]
+    CreationLimitExceededException: Type[BotocoreClientError]
+    DuplicateRecordException: Type[BotocoreClientError]
+    ExpiredNextTokenException: Type[BotocoreClientError]
+    InternalErrorException: Type[BotocoreClientError]
+    InvalidNextTokenException: Type[BotocoreClientError]
+    InvalidParameterException: Type[BotocoreClientError]
+    NotFoundException: Type[BotocoreClientError]
 
 
 class BudgetsClient:
     """
-    [Budgets.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client)
+    [Budgets.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client)
     """
 
     meta: ClientMeta
@@ -67,7 +73,7 @@ class BudgetsClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client.can_paginate)
         """
 
     def create_budget(
@@ -77,7 +83,7 @@ class BudgetsClient:
         NotificationsWithSubscribers: List[NotificationWithSubscribersTypeDef] = None,
     ) -> Dict[str, Any]:
         """
-        [Client.create_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.create_budget)
+        [Client.create_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client.create_budget)
         """
 
     def create_notification(
@@ -88,7 +94,7 @@ class BudgetsClient:
         Subscribers: List["SubscriberTypeDef"],
     ) -> Dict[str, Any]:
         """
-        [Client.create_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.create_notification)
+        [Client.create_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client.create_notification)
         """
 
     def create_subscriber(
@@ -99,19 +105,19 @@ class BudgetsClient:
         Subscriber: "SubscriberTypeDef",
     ) -> Dict[str, Any]:
         """
-        [Client.create_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.create_subscriber)
+        [Client.create_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client.create_subscriber)
         """
 
     def delete_budget(self, AccountId: str, BudgetName: str) -> Dict[str, Any]:
         """
-        [Client.delete_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.delete_budget)
+        [Client.delete_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client.delete_budget)
         """
 
     def delete_notification(
         self, AccountId: str, BudgetName: str, Notification: "NotificationTypeDef"
     ) -> Dict[str, Any]:
         """
-        [Client.delete_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.delete_notification)
+        [Client.delete_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client.delete_notification)
         """
 
     def delete_subscriber(
@@ -122,12 +128,12 @@ class BudgetsClient:
         Subscriber: "SubscriberTypeDef",
     ) -> Dict[str, Any]:
         """
-        [Client.delete_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.delete_subscriber)
+        [Client.delete_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client.delete_subscriber)
         """
 
     def describe_budget(self, AccountId: str, BudgetName: str) -> DescribeBudgetResponseTypeDef:
         """
-        [Client.describe_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.describe_budget)
+        [Client.describe_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client.describe_budget)
         """
 
     def describe_budget_performance_history(
@@ -139,21 +145,21 @@ class BudgetsClient:
         NextToken: str = None,
     ) -> DescribeBudgetPerformanceHistoryResponseTypeDef:
         """
-        [Client.describe_budget_performance_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.describe_budget_performance_history)
+        [Client.describe_budget_performance_history documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client.describe_budget_performance_history)
         """
 
     def describe_budgets(
         self, AccountId: str, MaxResults: int = None, NextToken: str = None
     ) -> DescribeBudgetsResponseTypeDef:
         """
-        [Client.describe_budgets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.describe_budgets)
+        [Client.describe_budgets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client.describe_budgets)
         """
 
     def describe_notifications_for_budget(
         self, AccountId: str, BudgetName: str, MaxResults: int = None, NextToken: str = None
     ) -> DescribeNotificationsForBudgetResponseTypeDef:
         """
-        [Client.describe_notifications_for_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.describe_notifications_for_budget)
+        [Client.describe_notifications_for_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client.describe_notifications_for_budget)
         """
 
     def describe_subscribers_for_notification(
@@ -165,7 +171,7 @@ class BudgetsClient:
         NextToken: str = None,
     ) -> DescribeSubscribersForNotificationResponseTypeDef:
         """
-        [Client.describe_subscribers_for_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.describe_subscribers_for_notification)
+        [Client.describe_subscribers_for_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client.describe_subscribers_for_notification)
         """
 
     def generate_presigned_url(
@@ -176,12 +182,12 @@ class BudgetsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client.generate_presigned_url)
         """
 
     def update_budget(self, AccountId: str, NewBudget: "BudgetTypeDef") -> Dict[str, Any]:
         """
-        [Client.update_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.update_budget)
+        [Client.update_budget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client.update_budget)
         """
 
     def update_notification(
@@ -192,7 +198,7 @@ class BudgetsClient:
         NewNotification: "NotificationTypeDef",
     ) -> Dict[str, Any]:
         """
-        [Client.update_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.update_notification)
+        [Client.update_notification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client.update_notification)
         """
 
     def update_subscriber(
@@ -204,7 +210,7 @@ class BudgetsClient:
         NewSubscriber: "SubscriberTypeDef",
     ) -> Dict[str, Any]:
         """
-        [Client.update_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Client.update_subscriber)
+        [Client.update_subscriber documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Client.update_subscriber)
         """
 
     @overload
@@ -212,7 +218,7 @@ class BudgetsClient:
         self, operation_name: Literal["describe_budgets"]
     ) -> DescribeBudgetsPaginator:
         """
-        [Paginator.DescribeBudgets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets)
+        [Paginator.DescribeBudgets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets)
         """
 
     @overload
@@ -220,7 +226,7 @@ class BudgetsClient:
         self, operation_name: Literal["describe_notifications_for_budget"]
     ) -> DescribeNotificationsForBudgetPaginator:
         """
-        [Paginator.DescribeNotificationsForBudget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget)
+        [Paginator.DescribeNotificationsForBudget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget)
         """
 
     @overload
@@ -228,8 +234,5 @@ class BudgetsClient:
         self, operation_name: Literal["describe_subscribers_for_notification"]
     ) -> DescribeSubscribersForNotificationPaginator:
         """
-        [Paginator.DescribeSubscribersForNotification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.52/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification)
+        [Paginator.DescribeSubscribersForNotification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.55/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification)
         """
-
-    def get_paginator(self, operation_name: str) -> Boto3Paginator:
-        pass
